/*
 *  path.h	
 *
 *  Written by:		Ullrich Hafner
 *  
 *  Copyright (C) 1998 Ullrich Hafner <hafner@bigfoot.de>
 *
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111, USA.
 */

/*
 *  $Date: 1999/03/03 11:29:34 $
 *  $Author: hafner $
 *  $Revision: 1.2 $
 *  $State: Exp $
 */

#ifndef _PATH_H
#define _PATH_H

void
path_dialog (GtkWidget *page, proplist_t key, proplist_t array,
	     GtkTooltips *tooltips, proplist_t info);

#endif /* not _PATH_H */
